====
Anti
====

Модуль для работы с браузерами, метрикой, вебмастером и пр.

 - Позволяет получать данные по позициям
 - Позволяет получать суп из поиска Яндекса и Гугла
 - Утилиты решают проблемы получения доноров, бэклинков, ТИЦ, PR и пр.

Импорт модулей:

from anti import openYandex, openGoogle, SeoParser, Metrika, Webmaster

0.7.1 Изменения

 - Добавлен балансировщик между серверами
 - Уменьшено количество sql запросов к базе

0.7.2
 - Балансировщик на redis

0.7.3
 - Fix: пустая выдача

0.7.4
 - Fix SeoParser: поправлена выдача страниц в индексе

1.0.1
 - Доделаны необходимые ф-ции для манипуляции с данными

1.0.2
 - Добавлена региональность

1.0.3
 - Добавлена ф-ция pages_of_site_in_index_google

1.0.4
 - Добавлены ф-ции получения возраста домена и посещений по liveinternet

1.0.5
 - Поправлена фитча с блоками. Добавлен 1ый пункт в whitelist. Добавлена ф-ция очищения текущего кэша.

1.1.0
 - Исправлена логика работы по сохранению и получению данных(Теперь все сохраняется в redis, а потом в postgres)

1.1.1
 - Добавлено получение позиций из кэша редиса

1.2.0
 - Удалены ф-ции multy. get_yandex_cache_pos получает позиции из redis. В базу данных теперь сохраняем отдельно.

1.2.1
 - Добавлена очистка кэша
